import requests
from collections import namedtuple

Nominee = namedtuple("Nominee", ['category', 'winner', 'primary', 'p_type', 'secondary', 's_type', "f_name", "f_winner"])

def safe_str(s):
	return s if not (s is None) else "Unknown"
	
def read_gg():
    result = requests.get("https://www.goldenglobes.com/winners-nominees/2018/all")
    if result.status_code != 200:
        raise Exception("Error downloading Golden Globe data: {}".format(result.status_code))

    c = result.content
    from bs4 import BeautifulSoup
    soup = BeautifulSoup(c, 'html.parser')
    categories = soup.find_all("div", "view-grouping")
    data = []
    
    # Purge 'None' results as they are not supported by the Python-to-JMP conversion
    for catg in categories:
        catg_name = safe_str(catg.next.string)
        catg_nominee_rows = catg.find_all("div", "views-row")
        for cnrow in catg_nominee_rows:
            a_div = cnrow.find("div", "views-field-field-nomination-is-winner")
            winner = a_div.get_text().strip()
            a_div = cnrow.find("div", "primary-nominee")
            p_nominee = safe_str(a_div.string)
            p_type = a_div.a['href'].split("/")[1]
            a_div = cnrow.find("div", "secondary-nominee")
            if a_div:
                s_nominee = safe_str(a_div.string)
                s_type = a_div.a['href'].split("/")[1]
            else:
                s_nominee = ""
                s_type = ""
            f_name = p_nominee if p_type == 'film' else s_nominee if s_type == 'film' else "N/A"
            f_winner = "Winner" if winner == "Winner" and (p_type == 'film' or s_type == 'film') else "Nominee"
            n = Nominee(catg_name, winner, p_nominee, p_type, s_nominee, s_type, f_name, f_winner)
            d = n._asdict()
            data.append(d)
    print(data)
    print(len(data))
    print(data[0])
    return data

if __name__ == "__main__":
    # execute only if run as a script
    read_gg()